@@ -1,9 +1,6 @@
-import socket
-from typing import List
-from typing import Dict
-import hashlib
 from enum import Enum
-from xmlrpc.client import Boolean
+import socket
+from typing import Dict
 
 import airtouch3.constants as const
 from airtouch3.helper import (
@@ -140,10 +137,11 @@ class AirTouch3:
     _TCP_PORT = 8899
 
     _tcp_ip = ""
-    name = ""
-    id = ""
+
     comms_status = AT3CommsStatus.ERROR
     comms_error = "Uninitialised"
+    name = ""
+    id = ""
     groups: Dict[int, AT3Group] = dict()
     ac_units: Dict[int, AT3AcUnit] = dict()
     sensors: Dict[str, AT3TempSensor] = dict()
@@ -155,8 +153,7 @@ class AirTouch3:
 
     def update_status(self) -> bool:
 
-        # Send a command to the Air Touch 3
-        # Byte1 = 1 means request status only
+        # Send a command to the Air Touch 3 to read status
         data = self._send_recieve(const.CMD_1_STATUS, 0, 0, 0)
         
         # Process the response, returning valid processing of reponse
@@ -218,7 +215,7 @@ class AirTouch3:
 
         data = self._send_recieve(const.CMD_1_AC_CTRL, acUnit, 
                                     const.CMD_4_AC_MODE, mode.value)
-
+        
         # Process the response, if fails, return none to indicate error
         if not self._process_response(data): return None
 
@@ -373,8 +370,9 @@ class AirTouch3:
             # otherwise, who cares right?
             acUnit.brand = int(response[const.DAOF_AC1_BRAND+a])
 
-            # Mode at in heat/cool etc
-            acUnit.mode = AT3AcMode(int(response[const.DAOF_AC1_MODE+a]))
+            # Mode at in heat/cool etc in bottom 4 bits
+            byte_value = response[const.DAOF_AC1_MODE+a]
+            acUnit.mode = AT3AcMode(int(byte_value & 0b0000_1111))
             
             # Fan Speed is only bottom 4 bits
             byte_value = response[const.DAOF_AC1_FAN+a]
@@ -459,7 +457,6 @@ class AirTouch3:
         rChk = calculate_checksum(rList)
         rList.extend(rChk)
         arr = bytes(rList)
-        print(*rList, sep = ", ")
 
         try:
             s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
